function actions(BEGIN,END,n,data,paraInd,R,E,indTar,orient,target,lastTar
             ,miam,Nvisites,patches,thr,r,TR,per,rho,sl,Tcrw,TW
             ,sdV,Ener,Costmvt,EnerRep,Births,miamTar,Mborn,Mparent,radRepro)

  # this function performs a simulation between the time steps BEGIN and END
  # for details about the parameters, see "exampleRun.jl"
  # for details about the variables, see "initialReproRand.jl"

  L = zeros(n)   # indicator to construct lastTar

  # a vector with a lot of angles
  if rho==0
    vecOrient = rand((END-BEGIN)*n)*2*pi
  elseif rho==1
    vecOrient = zeros((END-BEGIN)*n)
  else
    sd = sqrt(-2*log(rho))
    vecOrient = randn((END-BEGIN)*n)*sd
  end


  for h in BEGIN:END
    R = updateR(R,r)     # update R

    for ind in shuffle(collect(1:n))  # so that the order in which individuals move and eat is random

      ## if the individual is alive
      if Ener[(h-1),ind] > 0

        ### correlated random walk
        #--------------------------------
        if E[ind]==1
          # amount of time in CRW
          Tcrw[ind] += 1

          # new movement orientation
          orient[ind] = orient[ind] + vecOrient[1]
          vecOrient = vecOrient[2:end]

          # new location
          newX = data[h-1,1,ind] + sl*cos(orient[ind])
          newY = data[h-1,2,ind] + sl*sin(orient[ind])
          newX, newY, orient[ind] = reflectboundary(newX,newY,orient[ind])  # reflection
          data[h,:,ind] = [newX,newY]

          # vector of all distances between the new location and all patches
          dist = sqrt((data[h,1,ind]-patches[:,1]).^2+(data[h,2,ind]-patches[:,2]).^2)

          # update memories & time since last visit
          paraInd[:,:,ind] = updateIbin(paraInd[:,:,ind],TR,TW)

          # if an unknown patch (or forgotten patch) is perceived
          if sum(paraInd[1,:,ind]) < size(paraInd,2)               # if there is at least one unknown patch
            if minimum(dist[find(paraInd[1,:,ind] .== 0)]) < per   # if the closest unknown patch is within the perceptual range
              E[ind] = 2
              indTar[ind] = find(dist.==minimum(dist[find(paraInd[1,:,ind].==0)]))[1]    # choose as target the closest patch
            end
          end

          # if the value of a known patch goes higher than the value threshold
          if (E[ind]==1)&(indTar[ind]>0)  # if a patch is not perceived and the individual has already visited at least one patch
            # calculate the attractiveness values of known patches
            paraInd[5,:,ind] = paraInd[1,:,ind].*(1-paraInd[3,:,ind]).*paraInd[4,:,ind]
            VDist = paraInd[5,:,ind]'./dist
            VDist[find(VDist.>0)] = VDist[find(VDist.>0)] + randn(size(VDist[find(VDist.>0)],1))*sdV

            if maximum(VDist) > thr
              E[ind] = 2
              indTar[ind] = find(VDist.==maximum(VDist))[1]
            end
          end

          # update the energetical state variable
          Ener[h,ind] = Ener[(h-1),ind] - Costmvt


        ### Directed Walk (no noise)
        #--------------------------------------
        elseif E[ind]==2

          # update memories & time since last visit
          paraInd[:,:,ind] = updateIbin(paraInd[:,:,ind],TR,TW)

          # how far away is the target?
          target[ind,:] = patches[indTar[ind],:]
          DIST = sqrt((data[h-1,1,ind]-target[ind,1])^2+(data[h-1,2,ind]-target[ind,2])^2)

          # if the target is less than 1 step away, go there and switch to E3 (foraging mode)
          if DIST < sl
            data[h,:,ind] = target[ind,:]
            E[ind] = 3

          # otherwise, directed walk without noise
          else
            orient[ind] = atan2(target[ind,2]-data[h-1,2,ind],target[ind,1]-data[h-1,1,ind])

            newX = data[h-1,1,ind]+sl*cos(orient[ind])
            newY = data[h-1,2,ind]+sl*sin(orient[ind])
            newX, newY, orient[ind] = reflectboundary(newX,newY,orient[ind])  # reflection
            data[h,:,ind] = [newX,newY]

            ## if an unknown patch is perceived, change target
            dist = sqrt((data[h,1,ind]-patches[:,1]).^2+(data[h,2,ind]-patches[:,2]).^2)
            if sum(paraInd[1,:,ind]) < size(paraInd,2)               # if there is at least one unknown patch
              if minimum(dist[find(paraInd[1,:,ind] .== 0)]) < per   # if the closest unknown patch is within the perceptual range
                indTar[ind] = find(dist.==minimum(dist[find(paraInd[1,:,ind].==0)]))[1]
              end
            end
          end

          # update the energetical state variable
          Ener[h,ind] = Ener[(h-1),ind] - Costmvt


        ## inside the patch
        #-----------------------
        else

          data[h,:,ind] = [data[h-1,1,ind],data[h-1,2,ind]]

          # update memories & time since last visit
          paraInd[:,:,ind] = updateIbin(paraInd[:,:,ind],TR,TW)

          # eats
          miam[ind] = miam[ind] + (R[1,indTar[ind]] - (R[2,indTar[ind]]/1000) )
          miamTar[L[ind]+1,ind] = R[1,indTar[ind]] - (R[2,indTar[ind]]/1000)
          Nvisites[ind] = Nvisites[ind]+1
          Ener[h,ind] = Ener[(h-1),ind] + (R[1,indTar[ind]] - (R[2,indTar[ind]]/1000) )

          # update memory of the visited patch
          paraInd[1,indTar[ind],ind]  = 1  ## patch is known
          paraInd[2,indTar[ind],ind]  = 0  ## time since last visit
          paraInd[3,indTar[ind],ind]  = 1  ## unwillingness to come back too soon

          # if the patch was already known, update the apparent value Q of the patch
          if paraInd[4,indTar[ind],ind] != 0
            paraInd[4,indTar[ind],ind] = mean([paraInd[4,indTar[ind],ind], R[1,indTar[ind]]])
          else
            paraInd[4,indTar[ind],ind] = R[1,indTar[ind]]
          end

          # calculate values of known patches
          dist = sqrt((data[h,1,ind]-patches[:,1]).^2+(data[h,2,ind]-patches[:,2]).^2)
          paraInd[5,:,ind] = paraInd[1,:,ind].*(1-paraInd[3,:,ind]).*paraInd[4,:,ind]
          VDist = paraInd[5,:,ind]'./dist
          VDist[find(VDist.>0)] = VDist[find(VDist.>0)] + randn(size(VDist[find(VDist.>0)],1))*sdV

          # depletion of the used patch
          R[1,indTar[ind]] = R[2,indTar[ind]]/1000

          # add the visited patch to lastTar
          lastTar[L[ind]+1,ind] = indTar[ind]
          L[ind] += 1

          # if the relative value of a known patch is above thr, choose as target
          if maximum(VDist) > thr
            E[ind] = 2
            indTar[ind] = find(VDist.==maximum(VDist))[1]
          end

          ## if an unknown patch is perceived, choose as target
          if sum(paraInd[1,:,ind]) < size(paraInd,2)               # if there is at least one unknown patch
            if minimum(dist[find(paraInd[1,:,ind] .== 0)]) < per   # if the closest unknown patch is within the perceptual range
              E[ind] = 2
              indTar[ind] = find(dist.==minimum(dist[find(paraInd[1,:,ind].==0)]))[1]
            end
          end

          # if none of the two above conditions is met, do a CRW
          if E[ind] != 2
            E[ind] = 1
          end
        end
      end
    end

    ## REPRODUCTION
    for ind in 1:n
     # if Ener is above the threshold EnerRep, reproduce
     if Ener[h,ind] > EnerRep
        # update Ener for the parent
        Ener[h,ind] = (rand(1)[1]*2*radRepro) + Mparent - radRepro

        # add an individual
        n += 1
        # update all the variables (add an individual)
        data,paraInd,orient,E,indTar,target,lastTar,miam,Nvisites,Tcrw,Ener,L,vecOrient,miamTar = Repro(ind,h,n,data,paraInd,orient,E,indTar,target,lastTar,miam,Nvisites,Tcrw,Ener,patches,L,vecOrient,rho,miamTar)

        # initialize the energetical state of the new individual
        Ener[h,n] = (rand(1)[1]*2*radRepro) + Mborn - radRepro

        # add the birth info to Births
        Births = cat(1,Births,[n h ind])
      end
    end

  end

  return (data,paraInd,orient,R,E,indTar,target,lastTar,miam,Nvisites,Tcrw,Ener,n,Births,miamTar)
end
