### use this script to run an example simulation in Julia 0.3.9
## see the Methods section of the paper for details on the parameters and the model

require("reflectboundary.jl")
require("updateIbin.jl")
require("updateR.jl")
require("actions.jl")
require("initial.jl")
require("Repro.jl")
require("events.jl")
require("simul.jl")


n_ini = 1        # initial number of individuals
nit = 200000     # number of time steps (must be a multiple of 5,000)

## landscape ##
R0 = ones(400)   # vector of maximal amounts of food in the resource patches
                 # (landscape is initialized at maximum fill-up)
                 # must be a vector of floating numbers
r=0.03           # resource renewal rate

## movement parameters ##
sl = 1           # movement speed
per = 2          # perception radius
rho = 0.8        # concentration parameter of the correlated random walk

## memory parameters ##
thr = 0.01       # attractiveness threshold
TW = 200         # working memory length
TR = 1000        # reference memory length
sdV = 0.002      # error of the estimation of patch quality

## demographic parameters ##
EnerRep = 500    # energetical state to be reached to reproduce
Costmvt = 0.05   # energetical cost of movement
Mborn = 100      # mean initial energetical state of newborns
Mparent = 250    # mean energetical states of parents after reproduction
radRepro = 10    # energetical states after reproduction are uniformly drawn
                 # between [Mborn-radRepro; Mborn+radRepro] for newborns
                 # between [Mparent-radRepro; Mparent+radRepro] for parent


result = simul(n_ini,nit,R0,rho,sl,r,TR,per,TW,sdV,Costmvt,thr,EnerRep,Mborn,Mparent,radRepro)

writecsv("Recap.csv",result[8])
writecsv("TAB.csv",result[7])
