function initial(n,nit,patches,R0,sl,Costmvt,Mparent,radRepro)

  # this functions initializes the variables used during a simulation

  # patches : patch locations as a two-column matrix
  # for other parameters see details in "exampleRun.jl"

  data = zeros(nit,2,n)    # movement matrices
  orient = rand(n)2pi      # orientation, in rad
  lastTar = zeros(nit,n)   # to remember all the patches that are visited by each individual
  miamTar = zeros(nit,n)   # to remember the amount of resources consumed at each patch visited by each individual

  # randomly draw initial location of individuals within a 100x100 square
  locstart = hcat(rand(n)*100,rand(n)*100)

  # initialize the 3 first movement steps
  for ind in 1:n
    data[1,:,ind] = locstart[ind,:]
    data[2,:,ind] = [locstart[ind,1]+sl*cos(orient[ind]), locstart[ind,2]+sl*sin(orient[ind])]
  end

  # Prepare information values matrices
  paraInd = zeros(5,size(patches,1),n)  # one matrix per individual
                                        # one column per patch
                                        # 1st row = 1 if patch is known, 0 otherwise
                                        # 2nd row = time since last visit if patch is known
                                        # 3rd row = 1 if sufficient time (TW) has NOT yet elapsed
                                        # 4th row = remembered apparent quality of the patch IF IT IS KNOWN
                                        # 5th row = expected value of the patch (not discounting for distance to be travelled)

  R = hcat(R0,R0)'      # one column per patch.
                        # 1st row : current amount of resources within patches
                        # 2nd row : maximum amount of resources within patches

  Ener = zeros(nit,n)   # one column per individual
                        # energetical state variable over time
  Ener[1,:] = rand(n)*2*radRepro + Mparent - radRepro
  Ener[2,:] = Ener[1,:]-Costmvt

  E = ones(n)          # behavioural state vector (1: random walk, 2: directed walk, 3: foraging)

  indTar = zeros(n)    # index of the patch target if the individual is going to a specific patch
  target = zeros(n,2)  # patch target locations

  miam = zeros(n)      # how much food is consumed by each inidividual (additive)
  Nvisites = zeros(n)  # how many patches are visited by each inidividual (additive)
  Tcrw = zeros(n)      # the amount of time each individual spends doing random walk

  return (data,orient,paraInd,R,E,indTar,target,lastTar,miam,Nvisites,Tcrw,Ener,miamTar)

end
