function simul(n_ini,nit,R0,rho,sl,r,TR,per,TW,sdV,Costmvt,thr,EnerRep,Mborn,Mparent,radRepro)

  # this function completes a simulation over nit time steps (MUST be a multiple of 5000)
  # see "exampleRun.jl" for details on the model parameters
  # outputs:
    # data: one matrix per individual giving x,y coordinates per time step
    # Ener: matrix of energetical states of individuals over time, one column per individuals
    # Tcrw: amount of time spent doing crw per individual
    # patches: location of resource patches in the environment
    # n: number of individuals (total, even those that have died)
    # Births, TAB, Recap: see below

  # initialize the number of individuals
  n = n_ini

  # randomly draw patch locations within a 100x100 square
  patches = hcat(rand(size(R0,1))*100,rand(size(R0,1))*100)

  nTot = convert(Int8,nit/5000)         # number of 5,000-time-steps time windows

  Births = hcat(1:n,ones(n),zeros(n))   # 1st column: individual id
                                        # 2nd column: time of birth
                                        # 3rd column: parent id

  Recap = zeros(nTot,4)   # 1st column: time window id
                          # 2nd column: nb of individuals alive at the beginning of the time window,
                          # 3rd column: mean amount of resources in the patches at the end of the time window,
                          # 4th column: std of the amount of resources in the patches at the end of the time window


  # TAB is a matrix of summary events for each individual alive at the beginning of each time window
  # see "events.jl" for details about what is stored in TAB
  TAB = zeros(2,11)

  data,orient,paraInd,R,E,indTar,target,lastTar,miam,Nvisites,Tcrw,Ener,miamTar = initial(n,nit,patches,R0,sl,Costmvt,Mparent,radRepro)

  data,paraInd,orient,R,E,indTar,target,lastTar,miam,Nvisites,Tcrw,Ener,n,Births,miamTar = actions(3,5000,n,data,paraInd,R,E,indTar,orient,target,lastTar,miam,Nvisites,patches,thr,
                                                                                               r,TR,per,rho,sl,Tcrw,TW,sdV,Ener,Costmvt,EnerRep,Births,miamTar,Mborn,Mparent,radRepro)

  Recap[1,:] = [1, size(find(Ener[1,:].>0),1), mean(R[1,:]), sqrt(var(R[1,:]))]
  TAB = events(1,TAB,data,Ener,Births,miam,Nvisites,lastTar,miamTar)

  for j in 2:nTot

    lastTar=zeros(5000,n)
    miamTar=zeros(5000,n)
    miam=zeros(n)
    Nvisites=zeros(n)
    Tcrw=zeros(n)
    data,paraInd,orient,R,E,indTar,target,lastTar,miam,Nvisites,Tcrw,Ener,n,Births,miamTar = actions(5000*(j-1)+1,5000*j,n,data,paraInd,R,E,indTar,orient,target,lastTar,miam,Nvisites,patches,thr,
                                                                                                 r,TR,per,rho,sl,Tcrw,TW,sdV,Ener,Costmvt,EnerRep,Births,miamTar,Mborn,Mparent,radRepro)

    Recap[j,:] = [j, size(find(Ener[5000*(j-1)+1,:].>0),1), mean(R[1,:]), sqrt(var(R[1,:]))]
    TAB = events(j,TAB,data,Ener,Births,miam,Nvisites,lastTar,miamTar)
  end

  TAB = TAB[3:size(TAB,1),:]
  return data,Ener,Tcrw,patches,n,Births,TAB,Recap
end

